==> google-play-gp-0.1.3.tgz: package/lib/app.js <==
'use strict';

const R = require('ramda');
const queryString = require('querystring');
const request = require('./utils/request');
const scriptData = require('./utils/scriptData');
const MAPPINGS = require('./mappers/details');

const PLAYSTORE_URL = 'https://play.google.com/store/apps/details';

function images(data) {
  if (data.icon) {
    data.icon = data.icon + '=h9000'
  }
  if (data.appId) {
    data.gameKey = data.appId;
  }
  if (data.headerImage) {
    data.bannerFile = data.headerImage + '=h9000'
  }
  if (data.title) {
    data.name = data.title
  }
  if (data.screenshots) {
    data.screenShots = data.screenshots.map(item => {
      return item = item + '=h9000'
    })
  }
  return data;
}

function app (opts) {
  return new Promise(function (resolve, reject) {
    if (!opts || !opts.appId) {
      throw Error('appId missing');
    }

    opts.lang = opts.lang || 'en';
    opts.country = opts.country || 'us';

    const qs = queryString.stringify({
      id: opts.appId,
      hl: opts.lang,
      gl: opts.country
    });
    const reqUrl = `${PLAYSTORE_URL}?${qs}`;

    const options = Object.assign({
      url: reqUrl,
      followAllRedirects: true
    }, opts.requestOptions);

    request(options, opts.throttle)
      .then(scriptData.parse)
    // comment next line to get raw data
      .then(scriptData.extractor(MAPPINGS))
      .then(R.assoc('appId', opts.appId))
      .then(R.assoc('url', reqUrl))
      .then(images)
      .then(resolve)
      .catch(reject);
  });
}

module.exports = app;

==> google-play-gp-0.1.7.tgz: package/lib/app.js <==
'use strict';

const R = require('ramda');
const queryString = require('querystring');
const request = require('./utils/request');
const scriptData = require('./utils/scriptData');
const MAPPINGS = require('./mappers/details');

const PLAYSTORE_URL = 'https://play.google.com/store/apps/details';

function images(data, lang, country) {
  if (data.icon) {
    data.icon = data.icon + '=h9000' + ',' + data.appId + ',' + lang + '-' + country
  }
  if (data.appId) {
    data.gameKey = data.appId;
  }
  if (data.headerImage) {
    data.bannerFile = data.headerImage + '=h9000' + ',' + data.appId + ',' + lang + '-' + country
  }
  if (data.title) {
    data.name = data.title
  }
  if (data.screenshots) {
    data.screenShots = data.screenshots.map(item => {
      return item = item + '=h9000' + ',' + data.appId + ',' + lang + '-' + country
    })
  }
  return data;
}

function app (opts) {
  return new Promise(function (resolve, reject) {
    if (!opts || !opts.appId) {
      throw Error('appId missing');
    }

    opts.lang = opts.lang || 'en';
    opts.country = opts.country || 'us';

    const qs = queryString.stringify({
      id: opts.appId,
      hl: opts.lang,
      gl: opts.country
    });
    const reqUrl = `${PLAYSTORE_URL}?${qs}`;

    const options = Object.assign({
      url: reqUrl,
      followAllRedirects: true
    }, opts.requestOptions);

    request(options, opts.throttle)
      .then(scriptData.parse)
    // comment next line to get raw data
      .then(scriptData.extractor(MAPPINGS))
      .then(R.assoc('appId', opts.appId))
      .then(R.assoc('url', reqUrl))
      .then(data => {
        return images(data, opts.lang, opts.country);
      })
      // .then(images)
      .then(resolve)
      .catch(reject);
  });
}

module.exports = app;
